#ifdef __
#undef __
#endif

#ifdef __STDC__
#define __(x) x
#else
#define __(x) ()
#endif

/*
 * XXX move this definition somewhere else, or separate hostmap and
 * host info header files
 */

struct icon {
    int refcount;
    unsigned int width;
    unsigned int height;
    Pixmap bits;
};

struct host_info {
    char *name;			/* name of the host */
    char string[255];		/* string to go under host name */
    int hostNumber;		/* relative host number (for histogram) */
    int numRunning;		/* number of host processes running */
    int numIdle;		/* number of host processes idle */
    int xpos;			/* x position on window */
    int ypos;			/* y position on window */
    struct icon *icon;		/* pointer to an icon for that host */
    struct rb_node *proc_list;	/* list of processes running on that node */
};

struct proc_info {
    int id;			/* HeNCE node id */
    int inst;			/* node instance # */
    int state;			/* current state */
};

void hmap_Init __(());
void hmap_DrawHost __((struct host_info *h));
/* void hmap_UnDrawHostStr __((Window w, struct host_info *h)); */
/* void hmap_DrawNetwork __((Window w)); */
void hmap_Refresh __(());
struct icon *hmap_ReadIcon __((Window w, char *filename));
int hmap_ReadIconList __((Window w, char *filename));
struct host_info *hmap_AddHost __((char *hostname));
void hmap_HostEvent __((struct host_info *h, int id, int inst,
			int oldstate, int newstate));
void hmap_ResetHosts __(());
void hmap_NukeHosts __(());
void hmap_MakeHostList __(());
extern char **hmap_HostList;
extern int hmap_NumHosts;
#undef __
